NXT-Python
==========

NXT-Python is a package for controlling a LEGO NXT robot using the Python
programming language. It can communicate using either USB or Bluetooth.

NXT-Python for Python 3 is still alpha version, please report any problem you
run into.

NXT-Python for Python 2 is no longer supported.

NXT-Python sources are available on `NXT-Python repository on Github`_ and
mirrored on `NXT-Python repository on sourcehut`_.

.. _NXT-Python repository on Github: https://github.com/schodet/nxt-python
.. _NXT-Python repository on sourcehut: https://sr.ht/~ni/nxt-python/

.. toctree::
   :maxdepth: 2

   installation
   handbook/index
   api/index
   migration
   about


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
